@@ -16,3 +16,16 @@ OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM_BOTH = "both"
 
 # Options which must be set as environment variables.
 ENV_OPTION_ROBOT_DAP_TIMEOUT = "ROBOT_DAP_TIMEOUT"
+
+
+ALL_ROBOT_OPTIONS = frozenset(
+    (
+        OPTION_ROBOT_PYTHON_EXECUTABLE,
+        OPTION_ROBOT_PYTHON_ENV,
+        OPTION_ROBOT_LANGUAGE_SERVER_TCP_PORT,
+        OPTION_ROBOT_LANGUAGE_SERVER_ARGS,
+        OPTION_ROBOT_VARIABLES,
+        OPTION_ROBOT_PYTHONPATH,
+        OPTION_ROBOT_COMPLETION_SECTION_HEADERS_FORM,
+    )
+)
